#!/bin/bash

source "batch_jobs/_experiment_configuration.sh"

# Actual time:   ["bert-base-uncased"]="??:??:??" ["albert-base-v2"]="??:??:??" ["roberta-base"]="??:??:??" ["gpt2"]="02:00:00"
declare -A time=(["bert-base-uncased"]="02:00:00" ["albert-base-v2"]="02:00:00" ["roberta-base"]="02:00:00" ["gpt2"]="02:00:00")


for model in ${inlp_masked_lm_models[@]}; do
    for score_type in ${stereoset_score_types[@]}; do
        for split in ${stereoset_splits[@]}; do
            for bias_type in ${bias_types[@]}; do
                experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_s-${score_type}_d-${split}"
                if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
                    echo ${experiment_id}
                    sbatch \
                        --time ${time[${model_to_model_name_or_path[${model}]}]} \
                        -J ${experiment_id} \
                        -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                        -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                        python_job.sh experiments/stereoset_debias.py \
                            --intrasentence_model ${model} \
                            --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                            --projection_matrix "${persistent_dir}/results/projection_matrix/projection_m-${debiased_model_to_base_model[${model}]}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_r-mean.pt" \
                            --score_type ${score_type} \
                            --split ${split} \
                            --bias_type ${bias_type}
                fi
            done
        done
    done
done


for model in ${cda_masked_lm_models[@]}; do
    for score_type in ${stereoset_score_types[@]}; do
        for split in ${stereoset_splits[@]}; do
            for bias_type in ${bias_types[@]}; do
                experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_s-${score_type}_d-${split}"
                if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
                    echo ${experiment_id}
                    sbatch \
                        --time ${time[${model_to_model_name_or_path[${model}]}]} \
                        -J ${experiment_id} \
                        -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                        -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                        python_job.sh experiments/stereoset_debias.py \
                            --intrasentence_model ${model} \
                            --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                            --load_path "${persistent_dir}/checkpoints/cda_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}" \
                            --score_type ${score_type} \
                            --split ${split} \
                            --bias_type ${bias_type}
                fi
            done
        done
    done
done


for model in ${dropout_masked_lm_models[@]}; do
    for score_type in ${stereoset_score_types[@]}; do
        for split in ${stereoset_splits[@]}; do
            experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_s-${score_type}_d-${split}"
            if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
                echo ${experiment_id}
                sbatch \
                    --time ${time[${model_to_model_name_or_path[${model}]}]} \
                    -J ${experiment_id} \
                    -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                    -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                    python_job.sh experiments/stereoset_debias.py \
                        --intrasentence_model ${model} \
                        --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                        --load_path "${persistent_dir}/checkpoints/dropout_c-${model_to_model_name_or_path[${model}]}" \
                        --score_type ${score_type} \
                        --split ${split}
            fi
        done
    done
done


for model in ${sentence_debias_masked_lm_models[@]}; do
    for score_type in ${stereoset_score_types[@]}; do
        for split in ${stereoset_splits[@]}; do
            for bias_type in ${bias_types[@]}; do
                experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_s-${score_type}_d-${split}"
                if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
                    echo ${experiment_id}
                    sbatch \
                        --time ${time[${model_to_model_name_or_path[${model}]}]} \
                        -J ${experiment_id} \
                        -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                        -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                        python_job.sh experiments/stereoset_debias.py \
                            --intrasentence_model ${model} \
                            --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                            --bias_direction "${persistent_dir}/results/subspace/subspace_m-${debiased_model_to_base_model[${model}]}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_r-mean.pt" \
                            --score_type ${score_type} \
                            --split ${split} \
                            --bias_type ${bias_type}
                fi
            done
        done
    done
done


for model in ${self_debias_masked_lm_models[@]}; do
    for split in ${stereoset_splits[@]}; do
        for bias_type in ${bias_types[@]}; do
            experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_s-likelihood_d-${split}"
            if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
                echo ${experiment_id}
                sbatch \
                    --time ${time[${model_to_model_name_or_path[${model}]}]} \
                    -J ${experiment_id} \
                    -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                    -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                    python_job.sh experiments/stereoset_debias.py \
                        --intrasentence_model ${model} \
                        --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                        --score_type "likelihood" \
                        --split ${split} \
                        --bias_type ${bias_type}
            fi
        done
    done
done


for model in ${inlp_causal_lm_models[@]}; do
    for split in ${stereoset_splits[@]}; do
        for bias_type in ${bias_types[@]}; do
            experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_s-likelihood_d-${split}"
            if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
                echo ${experiment_id}
                sbatch \
                    --time ${time[${model_to_model_name_or_path[${model}]}]} \
                    -J ${experiment_id} \
                    -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                    -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                    python_job.sh experiments/stereoset_debias.py \
                        --intrasentence_model ${model} \
                        --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                        --projection_matrix "${persistent_dir}/results/projection_matrix/projection_m-${debiased_model_to_base_model[${model}]}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_r-mean.pt" \
                        --score_type "likelihood" \
                        --split ${split} \
                        --bias_type ${bias_type}
            fi
        done
    done
done


for model in ${inlp_causal_lm_models[@]}; do
    for split in ${stereoset_splits[@]}; do
        for bias_type in ${bias_types[@]}; do
            experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_s-likelihood_d-${split}"
            if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
                echo ${experiment_id}
                sbatch \
                    --time ${time[${model_to_model_name_or_path[${model}]}]} \
                    -J ${experiment_id} \
                    -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                    -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                    python_job.sh experiments/stereoset_debias.py \
                        --intrasentence_model ${model} \
                        --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                        --projection_matrix "${persistent_dir}/results/projection_matrix/projection_m-${debiased_model_to_base_model[${model}]}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_r-mean.pt" \
                        --score_type "likelihood" \
                        --split ${split} \
                        --bias_type ${bias_type}
            fi
        done
    done
done


for model in ${sentence_debias_causal_lm_models[@]}; do
    for split in ${stereoset_splits[@]}; do
        for bias_type in ${bias_types[@]}; do
            experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_s-likelihood_d-${split}"
            if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
                echo ${experiment_id}
                sbatch \
                    --time ${time[${model_to_model_name_or_path[${model}]}]} \
                    -J ${experiment_id} \
                    -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                    -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                    python_job.sh experiments/stereoset_debias.py \
                        --intrasentence_model ${model} \
                        --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                        --bias_direction "${persistent_dir}/results/subspace/subspace_m-${debiased_model_to_base_model[${model}]}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_r-mean.pt" \
                        --score_type "likelihood" \
                        --split ${split} \
                        --bias_type ${bias_type}
            fi
        done
    done
done


for model in ${cda_causal_lm_models[@]}; do
    for split in ${stereoset_splits[@]}; do
        for bias_type in ${bias_types[@]}; do
            experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_s-likelihood_d-${split}"
            if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
                echo ${experiment_id}
                sbatch \
                    --time ${time[${model_to_model_name_or_path[${model}]}]} \
                    -J ${experiment_id} \
                    -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                    -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                    python_job.sh experiments/stereoset_debias.py \
                        --intrasentence_model ${model} \
                        --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                        --load_path "${persistent_dir}/checkpoints/cda_m-${debiased_model_to_masked_lm_model[${model}]}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}" \
                        --score_type "likelihood" \
                        --split ${split} \
                        --bias_type ${bias_type}
            fi
        done
    done
done


for model in ${dropout_causal_lm_models[@]}; do
    for split in ${stereoset_splits[@]}; do
        experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_s-likelihood_d-${split}"
        if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
            echo ${experiment_id}
            sbatch \
                --time ${time[${model_to_model_name_or_path[${model}]}]} \
                -J ${experiment_id} \
                -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                python_job.sh experiments/stereoset_debias.py \
                    --intrasentence_model ${model} \
                    --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                    --load_path "${persistent_dir}/checkpoints/dropout_m-${debiased_model_to_masked_lm_model[${model}]}_c-${model_to_model_name_or_path[${model}]}" \
                    --score_type "likelihood" \
                    --split ${split}
        fi
    done
done


for model in ${self_debias_causal_lm_models[@]}; do
    for split in ${stereoset_splits[@]}; do
        for bias_type in ${bias_types[@]}; do
            experiment_id="stereoset_intra-${model}_c-${model_to_model_name_or_path[${model}]}_t-${bias_type}_s-likelihood_d-${split}"
            if [ ! -f "${persistent_dir}/results/stereoset/${experiment_id}.json" ]; then
                echo ${experiment_id}
                sbatch \
                    --time ${time[${model_to_model_name_or_path[${model}]}]} \
                    -J ${experiment_id} \
                    -o $HOME/scratch/debias-eval/logs/%x.%j.out \
                    -e $HOME/scratch/debias-eval/logs/%x.%j.err \
                    python_job.sh experiments/stereoset_debias.py \
                        --intrasentence_model ${model} \
                        --model_name_or_path ${model_to_model_name_or_path[${model}]} \
                        --score_type "likelihood" \
                        --split ${split} \
                        --bias_type ${bias_type}
            fi
        done
    done
done
